# Generated by Django 3.0.11 on 2021-01-26 08:49

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Department',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='QRCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, default='', max_length=100, unique=True)),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('short_uuid', models.SlugField(blank=True, null=True, unique=True)),
                ('basic_info', models.TextField(blank=True, default='')),
                ('mode', models.CharField(choices=[('kiosk', 'Kiosk Mode'), ('redirect', 'Redirect Mode'), ('info_page', 'Information Page Mode')], default='redirect', help_text='\nSets the mode this code is in.<br/>\nKiosk Mode: Show buttons to choose a link from<br/>\nRedirect Mode: Instantly redirects to the url with the highest priority.<br/>\nInformation Page Mode: Show basic info with links to different urls\n', max_length=16)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('last_updated', models.DateTimeField(auto_now=True)),
                ('department', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='qrcodes', to='qrtoolkit_core.Department')),
            ],
        ),
        migrations.CreateModel(
            name='LinkUrl',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, default='', help_text='Name of the url. Used in buttons and links when a code is scanned.', max_length=64)),
                ('url', models.URLField(blank=True, default='', help_text='redirect to external page')),
                ('priority', models.FloatField(default=1)),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='urls', to='qrtoolkit_core.QRCode')),
            ],
            options={
                'ordering': ['-priority'],
            },
        ),
        migrations.CreateModel(
            name='ApiHit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('hit_date', models.DateTimeField(auto_now_add=True)),
                ('action', models.CharField(choices=[('basic_info', 'Basic Info'), ('kiosk', 'Kiosk'), ('json', 'Json Response'), ('redirect', 'Redirect'), ('error', 'Error')], default='basic_info', max_length=16)),
                ('message', models.CharField(blank=True, help_text='Extra information about errors or other extra info', max_length=255, null=True)),
                ('code', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='hits', to='qrtoolkit_core.QRCode')),
            ],
            options={
                'ordering': ['-hit_date'],
            },
        ),
    ]



# Generated by Django 3.0.11 on 2021-02-02 12:57

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qrcode',
            name='department',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='qrcodes', to='qrtoolkit_core.Department'),
        ),
        migrations.AlterField(
            model_name='qrcode',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4),
        ),
    ]



from django import forms
from django.core import validators

QrKindTypes = [
    ('svg', 'Svg'),
    ('png', 'Png'),
    ('pdf', 'Pdf')
]


class HexField(forms.CharField):
    def __init__(self, **kwargs):
        super(HexField, self).__init__(max_length=7, min_length=4, **kwargs)
        self.validators.append(validators.RegexValidator(regex='^#[0-9A-Fa-f]{3}(?:[0-9A-Fa-f]{3})?$'))


class QrGenerateForm(forms.Form):
    query = forms.HiddenInput()
    kind = forms.ChoiceField(choices=QrKindTypes, required=False, initial='svg')
    light = HexField(required=False, initial='#FFFFFF', widget=forms.TextInput(attrs={'type': 'color'}))
    dark = HexField(required=False, initial='#000000', widget=forms.TextInput(attrs={'type': 'color'}))
    scale = forms.IntegerField(required=False, initial=3)

    def clean_kind(self):
        if not self['kind'].html_name in self.data:
            return self.fields['kind'].initial
        return self.cleaned_data['kind']

    def clean_light(self):
        if not self['light'].html_name in self.data:
            return self.fields['light'].initial
        return self.cleaned_data['light']

    def clean_dark(self):
        if not self['dark'].html_name in self.data:
            return self.fields['dark'].initial
        return self.cleaned_data['dark']

    def clean_scale(self):
        if not self['scale'].html_name in self.data:
            return self.fields['scale'].initial
        return self.cleaned_data['scale']
